@@ -1,4 +1,3 @@
-/* $Id: acconfig.h,v 1.7 1998/10/13 20:44:34 roessler Exp $ */
 
 /* Is this the international version? */
 #undef SUBVERSION
@@ -23,7 +22,6 @@
 
 /* What is your domain name? */
 #undef DOMAIN
-@TOP@
 
 /* Mutt version info */
 #undef VERSION
@@ -97,9 +95,6 @@
 /* Does your curses library support color? */
 #undef HAVE_COLOR
 
-/* Are we using GNU rx? */
-#undef USE_GNU_RX
-
 /* Compiling with SLang instead of curses/ncurses? */
 #undef USE_SLANG_CURSES
 
@@ -137,4 +132,11 @@
 /* Define as 1 if you have gettext and don't want to use GNU gettext.  */
 #undef HAVE_GETTEXT
 
+/* Do we have stpcpy? */
 #undef HAVE_STPCPY
+
+/* Use the included regex.c? */
+#undef USE_GNU_REGEX
+
+/* Do we have gpgm installed? */
+#undef HAVE_GPGM
