@@ -1,4 +1,3 @@
-static const char rcsid[]="$Id: copy.c,v 2.0 1998/12/12 08:05:59 roessler Rel $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -405,6 +404,7 @@ static int count_delete_lines (FILE *fp, BODY *b, long *length, size_t datelen)
  	M_CM_DISPLAY	displaying output to the user
 	M_CM_UPDATE	update structures in memory after syncing
 	M_CM_DECODE_PGP	used for decoding PGP messages
+        M_CM_CHARCONV	perform character set conversion
    chflags	flags to mutt_copy_header()
  */
 
@@ -497,6 +497,10 @@ _mutt_copy_message (FILE *fpout, FILE *fpin, HEADER *hdr, BODY *body,
       s.prefix = prefix;
     if (flags & M_CM_DISPLAY)
       s.flags |= M_DISPLAY;
+    if (flags & M_CM_WEED)
+      s.flags |= M_WEED;
+    if (flags & M_CM_CHARCONV)
+      s.flags |= M_CHARCONV;
 
 #ifdef _PGPPATH
     if (flags & M_CM_VERIFY)
@@ -592,6 +596,9 @@ _mutt_append_message (CONTEXT *dest, FILE *fpin, CONTEXT *src, HEADER *hdr,
     chflags |= CH_FROM;
   chflags |= (dest->magic == M_MAILDIR ? CH_NOSTATUS : CH_UPDATE);
   r = _mutt_copy_message (msg->fp, fpin, hdr, body, flags, chflags);
+  if (mx_commit_message (msg, dest) != 0)
+    r = -1;
+
   mx_close_message (&msg);
   return r;
 }
