@@ -45,7 +45,6 @@ WHERE char *ImapUser INITVAL (NULL);
 WHERE char *ImapPass INITVAL (NULL);
 WHERE short ImapCheckTime;
 #endif
-WHERE char *InReplyTo;
 WHERE char *Inbox;
 WHERE char *Ispell;
 WHERE char *Locale;
@@ -110,8 +109,10 @@ WHERE short SendmailWait;
 WHERE short Timeout;
 WHERE short WriteInc;
 
-/* vector to store received signals */
-WHERE short Signals INITVAL (0);
+/* flags for received signals */
+WHERE volatile sig_atomic_t SigAlrm INITVAL (0);
+WHERE volatile sig_atomic_t SigInt INITVAL (0);
+WHERE volatile sig_atomic_t SigWinch INITVAL (0);
 
 WHERE int CurrentMenu;
 
