@@ -1,4 +1,3 @@
-static const char rcsid[]="$Id: init.c,v 2.0 1998/12/12 08:06:30 roessler Rel $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -749,8 +748,23 @@ static int parse_set (BUFFER *tmp, BUFFER *s, unsigned long data, BUFFER *err)
     { 
       if (s && *s->dptr == '=')
       {
-	snprintf (err->data, err->dsize, _("%s is a boolean var!"), tmp->data);
-	return (-1);
+	if (unset || inv || query)
+	{
+	  snprintf (err->data, err->dsize, "Usage: set variable=yes|no");
+	  return (-1);
+	}
+
+	s->dptr++;
+	mutt_extract_token (tmp, s, 0);
+	if (mutt_strcasecmp ("yes", tmp->data) == 0)
+	  unset = inv = 0;
+	else if (mutt_strcasecmp ("no", tmp->data) == 0)
+	  unset = 1;
+	else
+	{
+	  snprintf (err->data, err->dsize, "Usage: set variable=yes|no");
+	  return (-1);
+	}
       }
 
       if (query)
@@ -1428,6 +1442,9 @@ int mutt_var_value_complete (char *buffer, size_t len, int pos)
 		  (*((short *) MuttVars[idx].data) & SORT_LAST) ? "last-" : "",
 		  p);
       }
+      else if (DTYPE (MuttVars[idx].type) == DT_BOOL)
+	snprintf (pt, dlen, "%s%s", tmp, 
+		  option (MuttVars[idx].data) ? "yes" : "no");
       else
 	return 0;
       return 1;
@@ -1610,12 +1627,17 @@ void mutt_init (int skip_sys_rc, LIST *commands)
 #ifdef _PGPPATH
 #ifdef _PGPV2PATH
   PgpV2 = safe_strdup (_PGPV2PATH);
+  PgpV6 = safe_strdup (_PGPV2PATH);
   if ((p = getenv("PGPPATH")) != NULL)
   {
     snprintf (buffer, sizeof (buffer), "%s/pubring.pgp", p);
     PgpV2Pubring = safe_strdup (buffer);
     snprintf (buffer, sizeof (buffer), "%s/secring.pgp", p); 
     PgpV2Secring = safe_strdup (buffer);
+    snprintf (buffer, sizeof (buffer), "%s/pubring.pkr", p);
+    PgpV6Pubring = safe_strdup (buffer);
+    snprintf (buffer, sizeof (buffer), "%s/secring.skr", p); 
+    PgpV6Secring = safe_strdup (buffer);
   }
   else
   {
@@ -1623,6 +1645,10 @@ void mutt_init (int skip_sys_rc, LIST *commands)
     PgpV2Pubring = safe_strdup (buffer);
     snprintf (buffer, sizeof (buffer), "%s/.pgp/secring.pgp", NONULL(Homedir));
     PgpV2Secring = safe_strdup (buffer);
+    snprintf (buffer, sizeof (buffer), "%s/.pgp/pubring.pkr", NONULL(Homedir));
+    PgpV6Pubring = safe_strdup (buffer);
+    snprintf (buffer, sizeof (buffer), "%s/.pgp/secring.skr", NONULL(Homedir));
+    PgpV6Secring = safe_strdup (buffer);
   }
 #endif
 
