@@ -129,7 +129,6 @@ struct option_t MuttVars[] = {
   { "imap_passive",	DT_BOOL, R_NONE, OPTIMAPPASSIVE, 1 },
 #endif
   { "implicit_autoview", DT_BOOL,R_NONE, OPTIMPLICITAUTOVIEW, 0},
-  { "in_reply_to",	DT_STR,	 R_NONE, UL &InReplyTo, UL "%i; from %n on %{!%a, %b %d, %Y at %I:%M:%S%p %Z}" },
   { "include",		DT_QUAD, R_NONE, OPT_INCLUDE, M_ASKYES },
   { "indent_string",	DT_STR,	 R_NONE, UL &Prefix, UL "> " },
   { "indent_str",	DT_SYN,  R_NONE, UL "indent_string", 0 },
@@ -187,6 +186,11 @@ struct option_t MuttVars[] = {
   { "pgp_v5_pubring",	DT_PATH, R_NONE, UL &PgpV3Pubring, 0 },
   { "pgp_v5_secring",	DT_PATH, R_NONE, UL &PgpV3Secring, 0 },
 
+  { "pgp_v6",		DT_PATH, R_NONE, UL &PgpV6, 0 },
+  { "pgp_v6_language",	DT_STR,	 R_NONE, UL &PgpV6Language, 0 },
+  { "pgp_v6_pubring",	DT_PATH, R_NONE, UL &PgpV6Pubring, 0 },
+  { "pgp_v6_secring",	DT_PATH, R_NONE, UL &PgpV6Secring, 0 },
+
   { "pgp_gpg",		DT_PATH, R_NONE, UL &PgpGpg, 0 },
   
 # ifdef HAVE_PGP2
