@@ -51,24 +51,28 @@
 #define IsAttach(x) (x && (x)->bdy)
 #define IsHeader(x) (x && (x)->hdr)
 
+static const char Not_available_in_this_menu[] = N_("Not available in this menu.");
+static const char Mailbox_is_read_only[] = N_("Mailbox is read-only.");
+static const char Function_not_permitted_in_attach_message_mode[] = N_("Function not permitted in attach-message mode.");
+
 #define CHECK_MODE(x)	if (!(x)) \
 			{ \
 			  	mutt_flushinp (); \
-				mutt_error _("Not available in this menu."); \
+				mutt_error _(Not_available_in_this_menu); \
 				break; \
 			}
 
 #define CHECK_READONLY	if (Context->readonly) \
 			{ \
 				mutt_flushinp (); \
-				mutt_error _("Mailbox is read-only.");	\
+				mutt_error _(Mailbox_is_read_only);	\
 				break; \
 			}
 
 #define CHECK_ATTACH if(option(OPTATTACHMSG)) \
 		     {\
 			mutt_flushinp (); \
-			mutt_error _("Function not permitted in attach-message mode."); \
+			mutt_error _(Function_not_permitted_in_attach_message_mode); \
 			break; \
 		     }
 
@@ -1659,13 +1663,13 @@ mutt_pager (const char *banner, const char *fname, int flags, pager_t *extra)
     mutt_clear_error ();
     mutt_curs_set (1);
 
-    if (Signals & S_INTERRUPT)
+    if (SigInt)
     {
       mutt_query_exit ();
       continue;
     }
 #if defined (USE_SLANG_CURSES) || defined (HAVE_RESIZETERM)
-    else if (Signals & S_SIGWINCH)
+    else if (SigWinch)
     {
       mutt_resize_screen ();
 
@@ -1710,7 +1714,7 @@ mutt_pager (const char *banner, const char *fname, int flags, pager_t *extra)
 	ch = 0;
       }
 
-      Signals &= ~S_SIGWINCH;
+      SigWinch = 0;
       continue;
     }
 #endif
@@ -1896,7 +1900,8 @@ mutt_pager (const char *banner, const char *fname, int flags, pager_t *extra)
 	  /* update the search pointers */
 	  i = 0;
 	  while (display_line (fp, &last_pos, &lineInfo, i, &lastLine, 
-				&maxLine, M_SEARCH, &QuoteList, &q_level,
+				&maxLine, M_SEARCH | (flags & M_PAGER_NSKIP),
+				&QuoteList, &q_level,
 				&force_redraw, &SearchRE) == 0)
 	    i++;
 
