@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 1996-1998 Michael R. Elkins <me@cs.hmc.edu>
+ * Copyright (C) 1999 Thomas Roessler <roessler@guug.de>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -43,6 +44,15 @@
 #include <string.h>
 #include <errno.h>
 
+static const char Mailbox_is_read_only[] = N_("Mailbox is read-only.");
+
+#define CHECK_READONLY if (Context->readonly) \
+{\
+    mutt_flushinp (); \
+    mutt_error _(Mailbox_is_read_only); \
+    break; \
+}
+
 static struct mapping_t AttachHelp[] = {
   { N_("Exit"),  OP_EXIT },
   { N_("Save"),  OP_SAVE },
@@ -711,7 +721,7 @@ copy_tagged_attachments (FILE *fpout, FILE *fpin, const char *boundary, BODY *bd
   {
     if (bdy->tagged)
     {
-      fprintf (fpout, "--%s\n", boundary);
+      fprintf (fpout, "\n--%s\n", boundary);
       fseek (fpin, bdy->hdr_offset, 0);
       mutt_copy_bytes (fpin, fpout, bdy->length + bdy->offset - bdy->hdr_offset);
     }
@@ -756,6 +766,7 @@ create_tagged_message (const char *tempfile,
     mutt_copy_bytes (src->fp, msg->fp, body->length);
   }
 
+  mx_commit_message (msg, &tmpctx);
   mx_close_message (&msg);
   mx_close_message (&src);
   mx_close_mailbox (&tmpctx);
@@ -777,7 +788,11 @@ static void reply_attachment_list (int op, int tag, HEADER *hdr, BODY *body)
   if (!tag && body->hdr)
   {
     hn = body->hdr;
-    hn->msgno = hdr->msgno; /* required for MH/maildir */
+    hn->msgno   = hdr->msgno; /* required for MH/maildir */
+    hn->replied = hdr->replied;
+    hn->read    = hdr->read;
+    hn->old	= hdr->old;
+    hn->changed = hdr->changed;
     ctx = Context;
   }
   else
@@ -791,8 +806,13 @@ static void reply_attachment_list (int op, int tag, HEADER *hdr, BODY *body)
 
   ci_send_message (op, NULL, NULL, ctx, hn);
 
-  if (hn->replied && !hdr->replied)
-    mutt_set_flag (Context, hdr, M_REPLIED, 1);
+  if (hn->replied)
+  {
+    if (Context != ctx)
+      mutt_set_flag (Context, hdr, M_REPLIED, 1);
+    else
+      _mutt_set_flag (Context, hdr, M_REPLIED, 1, 0);
+  }
 
   if (ctx != Context)
   {
@@ -891,7 +911,7 @@ void mutt_view_attachments (HEADER *hdr)
 #ifdef _PGPPATH
   if((hdr->pgp & PGPENCRYPT) && !pgp_valid_passphrase())
   {
-    mx_close_message(&msg);
+    mx_close_message (&msg);
     return;
   }
   
@@ -970,6 +990,7 @@ void mutt_view_attachments (HEADER *hdr)
 	break;
 
       case OP_DELETE:
+	CHECK_READONLY;
 
 #ifdef _PGPPATH
         if (hdr->pgp)
@@ -1020,31 +1041,32 @@ void mutt_view_attachments (HEADER *hdr)
         break;
 
       case OP_UNDELETE:
-       if (!menu->tagprefix)
-       {
-	 idx[menu->current]->content->deleted = 0;
-	 if (option (OPTRESOLVE) && menu->current < menu->max - 1)
-	 {
-	   menu->current++;
-	   menu->redraw = REDRAW_MOTION_RESYNCH;
-	 }
-	 else
-	   menu->redraw = REDRAW_CURRENT;
-       }
-       else
-       {
-	 int x;
+	CHECK_READONLY;
+	if (!menu->tagprefix)
+	{
+	  idx[menu->current]->content->deleted = 0;
+	  if (option (OPTRESOLVE) && menu->current < menu->max - 1)
+	  {
+	    menu->current++;
+	    menu->redraw = REDRAW_MOTION_RESYNCH;
+	  }
+	  else
+	    menu->redraw = REDRAW_CURRENT;
+	}
+	else
+	{
+	  int x;
 
-	 for (x = 0; x < menu->max; x++)
-	 {
-	   if (idx[x]->content->tagged)
-	   {
-	     idx[x]->content->deleted = 0;
-	     menu->redraw = REDRAW_INDEX;
-	   }
-	 }
-       }
-       break;
+ 	  for (x = 0; x < menu->max; x++)
+	  {
+	    if (idx[x]->content->tagged)
+	    {
+	      idx[x]->content->deleted = 0;
+	      menu->redraw = REDRAW_INDEX;
+	    }
+	  }
+        }
+        break;
 
       case OP_BOUNCE_MESSAGE:
         CHECK_ATTACH;
